@@ -212,11 +212,13 @@ def alerts_query(context, query):
 
 @alerts.command(name='list')
 @click.option('--active', default=False, is_flag=True)
-@click.option('--more_info', default=False, is_flag=True)
+@click.option('--more-info', default=False, is_flag=True)
 @click.option('--team-name', 'team_name', default=False)
-@click.option('--limit', default=50)
+@click.option('--out-of-office-hours', default=False, is_flag=True)
+@click.option('--not-filtered', default=False, is_flag=True)
+@click.option('--limit', default=100)
 @click.pass_context
-def alerts_list(context, active, limit, more_info, team_name):  # pylint: disable=too-many-branches
+def alerts_list(context, active, limit, more_info, team_name, out_of_office_hours, not_filtered):  # pylint: disable=too-many-branches
     """
     Function to list alerts
 
@@ -238,24 +240,39 @@ def alerts_list(context, active, limit, more_info, team_name):  # pylint: disabl
         raise click.UsageError(
             "Specify the teamname using --teamname."
         )
-    result = context.obj['opsgenie'].list_alerts_by_team(team_name, limit)
-    sortedlist = sorted(result['data'], key=itemgetter('status'))
+
+    if not_filtered:
+        result = context.obj['opsgenie'].query_alerts(f"responders:{team_name} AND tag != filtered AND tag != Filtered", limit)
+    else:
+        result = context.obj['opsgenie'].query_alerts(f"responders:{team_name}", limit)
+    sortedlist = sorted(result, key=itemgetter('status'))
+
     if more_info:
         format_table = PrettyTable(['id', 'name', 'status', 'acknowledged',
                                     'createdAt', 'tags', 'source', 'integration'])
     else:
         format_table = PrettyTable(['id', 'name', 'status', 'acknowledged', 'createdAt'])
     for item in sortedlist:
-        if active:
+        if out_of_office_hours:
+            alert_dt = (pendulum.parse(item['createdAt'])).in_tz('Europe/Amsterdam')
+            if not item['tags']:
+                item['tags'] = None
+            if (alert_dt.hour >= 17) or (alert_dt.hour < 8):
+                if more_info:
+                    format_table.add_row([item['id'], item['message'], item['status'], item['acknowledged'],
+                                          alert_dt.to_datetime_string(), item['tags'], item['source'], item['integration']['name']])
+                else:
+                    format_table.add_row([item['id'], item['message'], item['status'], item['acknowledged'], created_at])
+        elif active:
             if item['status'] == 'open' and not item['acknowledged']:
-                created_at = datetime.strptime(item['createdAt'], '%Y-%m-%dT%H:%M:%S.%fZ').strftime('%Y-%m-%d %H:%M:%S')
+                created_at = ((pendulum.parse(item['createdAt'])).in_tz('Europe/Amsterdam')).to_datetime_string()
                 if more_info:
                     format_table.add_row([item['id'], item['message'], item['status'], item['acknowledged'],
                                           created_at, item['tags'], item['source'], item['integration']['name']])
                 else:
                     format_table.add_row([item['id'], item['message'], item['status'], item['acknowledged'], created_at])
         else:
-            created_at = datetime.strptime(item['createdAt'], '%Y-%m-%dT%H:%M:%S.%fZ').strftime('%Y-%m-%d %H:%M:%S')
+            created_at = ((pendulum.parse(item['createdAt'])).in_tz('Europe/Amsterdam')).to_datetime_string()
             if more_info:
                 format_table.add_row([item['id'], item['message'], item['status'], item['acknowledged'],
                                       created_at, item['tags'], item['source'], item['integration']['name']])
@@ -284,8 +301,11 @@ def alerts_get(context, id_):
 
 @alerts.command(name='count')
 @click.option('--team-name', 'team_name', default=False)
+@click.option('--not-filtered', default=False, is_flag=True)
+@click.option('--out-of-office-hours', default=False, is_flag=True)
+@click.option('--limit', default=100)
 @click.pass_context
-def alerts_count(context, team_name):
+def alerts_count(context, team_name, not_filtered, out_of_office_hours, limit):
     """
     Function to show which alerts were noisy
 
@@ -304,14 +324,19 @@ def alerts_count(context, team_name):
         raise click.UsageError(
             "Specify the teamname using --teamname."
         )
-    url = f"https://api.opsgenie.com/v2/alerts?limit=100&query=teams:{team_name}"
-    headers = {
-        'Authorization': f"GenieKey {context.obj.get('apikey')}",
-        'Content-Type': "application/json"
-    }
-    response = requests.get(url, headers=headers)
-    parsed = json.loads(response.text)
-    dictionary = collections.Counter(item['message'] for item in parsed['data'])
+    if not_filtered:
+        result = context.obj['opsgenie'].query_alerts(f"responders:{team_name} AND tag != filtered AND tag != Filtered", limit)
+    else:
+        result = context.obj['opsgenie'].query_alerts(f"responders:{team_name}", limit)
+    if out_of_office_hours:
+        alerts = []
+        for alert in result:
+            alert_dt = pendulum.parse(alert['createdAt'])
+            if (alert_dt.hour >= 17) or (alert_dt.hour < 8):
+                alerts += [alert]
+    else:
+        alerts = result
+    dictionary = collections.Counter(item['message'] for item in alerts)
     sorted_by_count = sorted(dictionary.items(), reverse=True, key=itemgetter(1))
     for alert in sorted_by_count:
         print(f"{alert[1]} - {alert[0]}")
@@ -890,8 +915,8 @@ def policy_maintenance_get(context, id_):
 
 @policy_maintenance.command(cls=DefaultHelp, name='set')
 @click.option('--description', prompt=True)
-@click.option('--start-date', 'start_date', help='Example: 2019-03-15T14:34:09Z')
-@click.option('--end-date', 'end_date', help='Example: 2019-03-15T15:34:09Z')
+@click.option('--start-date', 'start_date', help='Example: 2019-03-15T14:34:09')
+@click.option('--end-date', 'end_date', help='Example: 2019-03-15T15:34:09')
 @click.option('--filter', 'filter_', multiple=True, cls=MutuallyExclusiveOption, mutually_exclusive=["id"],
               help='Filter down based on the name of the alert policy.')
 @click.option('--state', type=click.Choice(['enabled', 'disabled']), default='enabled', help='State of rule that \
@@ -956,13 +981,11 @@ def policy_maintenance_set(context,  # pylint: disable=too-many-branches, too-ma
                 id_.append(temp_id)
                 filters_enabled.append([item['name'] for item in filtered_results if item.get('id') == temp_id][0])
     if all([start_date, end_date]):
-        start = datetime.strptime(start_date, "%Y-%m-%dT%H:%M:%SZ")
-        end = datetime.strptime(end_date, "%Y-%m-%dT%H:%M:%SZ")
-        startdatetime = start.astimezone(pytz.utc).strftime("%Y-%m-%dT%H:%M:%SZ")
-        enddatetime = end.astimezone(pytz.utc).strftime("%Y-%m-%dT%H:%M:%SZ")
+        start_dt = pendulum.parse(start_date, tz='Europe/Amsterdam')
+        end_dt = pendulum.parse(end_date, tz='Europe/Amsterdam')
     else:
-        start = datetime.now().astimezone(pytz.utc)
-        end = start + timedelta(hours=hours)
+        start_dt = pendulum.now(tz='Europe/Amsterdam')
+        end_dt = start_dt.add(hours=hours)
     if hours:
         result = context.obj['opsgenie'].set_maintenance_hours(context.obj.get('teamid'),
                                                                hours,
@@ -972,8 +995,8 @@ def policy_maintenance_set(context,  # pylint: disable=too-many-branches, too-ma
                                                                id_)
     if all([start_date, end_date]):
         result = context.obj['opsgenie'].set_maintenance_schedule(context.obj.get('teamid'),
-                                                                  startdatetime,
-                                                                  enddatetime,
+                                                                  start_dt.isoformat(),
+                                                                  end_dt.isoformat(),
                                                                   entity,
                                                                   description,
                                                                   state,
@@ -985,12 +1008,10 @@ def policy_maintenance_set(context,  # pylint: disable=too-many-branches, too-ma
                   f"Time: {hours}hours\n\t"
                   f"Policies enabled: {filters_enabled}")
         if start_date and end_date:
-            startdatetime = start.strftime('%Y-%m-%d %H:%M:%S')
-            enddatetime = end.strftime('%Y-%m-%d %H:%M:%S')
             print(f"✓ - Maintenance policy created.\n\t"
                   f"Description: {description}\n\t"
-                  f"Start: {startdatetime}\n\t"
-                  f"End: {enddatetime}\n\t"
+                  f"Start: {start_dt.to_datetime_string()}\n\t"
+                  f"End: {end_dt.to_datetime_string()}\n\t"
                   f"Policies enabled: {filters_enabled}")
 
 
@@ -1169,15 +1190,13 @@ def policy_maintenance_list(context, nonexpired, past):
         result = context.obj['opsgenie'].list_maintenance()
     format_table = PrettyTable(['id', 'status', 'description', 'type', 'startdate', 'enddate'])
     for item in result['data']:
-        if item['time']['endDate']:
-            truncated_end_date = (item['time']['endDate'].replace('Z', '')).split(".")[0]
-            modified_end_date = datetime.fromisoformat(truncated_end_date).strftime('%Y-%m-%d %H:%M:%S')
+        if 'endDate' in item['time']:
+            end_date = (pendulum.parse(item['time']['endDate'])).to_datetime_string()
         else:
-            item['time']['endDate'] = None
-        truncated_start_date = (item['time']['startDate'].replace('Z', '')).split(".")[0]
-        modified_start_date = datetime.fromisoformat(truncated_start_date).strftime('%Y-%m-%d %H:%M:%S')
+            end_date = None
+        start_date = (pendulum.parse(item['time']['startDate'])).to_datetime_string()
         format_table.add_row([item['id'], item['status'], item['description'],
-                              item['time']['type'], modified_start_date, modified_end_date])
+                              item['time']['type'], start_date, end_date])
     print(format_table)
 
 
@@ -1570,20 +1589,12 @@ def schedules_timeline(context, team_name, history, expand, interval, intervalun
     print(f'\n On-call schedules - {rotation.lower()}')
 
     for item in result['data'][f'{rotation}']['rotations'][0]['periods']:
-        if not history and datetime.now().date() > datetime.strptime((item['startDate'].replace('Z', '')).split(".")[0], "%Y-%m-%dT%H:%M:%S").date():
+        if not history and datetime.now().date() > pendulum.parse(item['startDate']):
             continue
         else:
-            time_zone = pytz.timezone("UTC")
-
-            start_dt_truncated = (item['startDate'].replace('Z', '')).split(".")[0]
-            start_utc_dt = time_zone.localize((datetime.fromisoformat(start_dt_truncated)))
-            start_ams_dt = (start_utc_dt.astimezone(pytz.timezone("Europe/Amsterdam"))).strftime('%Y-%m-%d %H:%M:%S')
-
-            end_dt_truncated = (item['endDate'].replace('Z', '')).split(".")[0]
-            end_utc_dt = time_zone.localize((datetime.fromisoformat(end_dt_truncated)))
-            end_ams_dt = (end_utc_dt.astimezone(pytz.timezone("Europe/Amsterdam"))).strftime('%Y-%m-%d %H:%M:%S')
-
-            format_table.add_row([item['recipient']['name'], start_ams_dt, end_ams_dt])
+            start_dt = pendulum.parse(item['startDate']).in_tz('Europe/Amsterdam')
+            end_dt = pendulum.parse(item['endDate']).in_tz('Europe/Amsterdam')
+            format_table.add_row([item['recipient']['name'], start_dt.to_datetime_string(), end_dt.to_datetime_string()])
     print(format_table)
 
 
@@ -1616,49 +1627,35 @@ def schedules_timeline(context, team_name, start_date, end_date, exclude_enginee
     ## show old schedule, filtered down in time:
     format_table = PrettyTable(['user', 'startdate', 'enddate'])
     print(f'\n Current On-call schedule')
-    start_date = datetime.strptime(start_date, "%Y-%m-%d").date()
-    end_date = datetime.strptime(end_date, "%Y-%m-%d").date()
+    start_date = pendulum.parse(start_date)
+    end_date = pendulum.parse(end_date)
     all_start_dates = []
     for item in result['data'][f'finalTimeline']['rotations'][0]['periods']:
-        item_date_value = datetime.strptime((item['startDate'].replace('Z', '')).split(".")[0], "%Y-%m-%dT%H:%M:%S").date()
+        item_date_value = pendulum.parse(item['startDate'])
         if start_date <= item_date_value and item_date_value < end_date:
-            all_start_dates += [(item['startDate'].replace('Z', '')).split(".")[0]]
-            time_zone = pytz.timezone("UTC")
+            all_start_dates += [item_date_value]
 
-            start_dt_truncated = (item['startDate'].replace('Z', '')).split(".")[0]
-            start_utc_dt = time_zone.localize((datetime.fromisoformat(start_dt_truncated)))
-            start_ams_dt = (start_utc_dt.astimezone(pytz.timezone("Europe/Amsterdam"))).strftime('%Y-%m-%d %H:%M:%S')
-
-            end_dt_truncated = (item['endDate'].replace('Z', '')).split(".")[0]
-            end_utc_dt = time_zone.localize((datetime.fromisoformat(end_dt_truncated)))
-            end_ams_dt = (end_utc_dt.astimezone(pytz.timezone("Europe/Amsterdam"))).strftime('%Y-%m-%d %H:%M:%S')
-
-            format_table.add_row([item['recipient']['name'], start_ams_dt, end_ams_dt])
+            start_dt = pendulum.parse(item['startDate']).in_tz('Europe/Amsterdam')
+            end_dt = pendulum.parse(item['endDate']).in_tz('Europe/Amsterdam')
+            format_table.add_row([item['recipient']['name'], start_dt.to_datetime_string(), end_dt.to_datetime_string()])
     print(format_table)
 
     ## get all the days for that period
-    all_start_dates
     format_table = PrettyTable(['user', 'startdate', 'enddate'])
     print(f'\n Proposed On-call schedule')
     copy_list_unique_engineers = list(unique_engineers)
     last_engineer = ""
     for date in all_start_dates:
-        time_zone = pytz.timezone("UTC")
-
         while True:
             randomNumber = random.randint(0, (len(copy_list_unique_engineers) - 1))
             engineer = copy_list_unique_engineers[randomNumber]
             if engineer != last_engineer:
                 break
 
-        start_utc_dt = time_zone.localize((datetime.fromisoformat(date)))
-        start_ams_dt = (start_utc_dt.astimezone(pytz.timezone("Europe/Amsterdam"))).strftime('%Y-%m-%d %H:%M:%S')
+        start_ams_dt = date.in_tz('Europe/Amsterdam')
+        stop_ams_dt = start_ams_dt.add(days=1)
+        format_table.add_row([engineer, start_ams_dt.to_datetime_string(), stop_ams_dt.to_datetime_string()])
 
-        end_date_x = str((datetime.strptime(date, "%Y-%m-%dT%H:%M:%S").date() + timedelta(days=1)))
-        stop_utc_dt = time_zone.localize((datetime.fromisoformat(end_date_x)))
-        stop_ams_dt = (stop_utc_dt.astimezone(pytz.timezone("Europe/Amsterdam"))).strftime('%Y-%m-%d %H:%M:%S')
-
-        format_table.add_row([engineer, start_ams_dt, stop_ams_dt])
         last_engineer = format_table._rows[-1][0]
         del copy_list_unique_engineers[randomNumber]
         if not copy_list_unique_engineers:
@@ -2072,10 +2069,8 @@ def override(context, team_name, engineer, hours, start_date, end_date):  # pyli
         end_dt = start_dt.add(hours=hours)
     elif start_date and end_date:
         start_dt = pendulum.parse(start_date, tz='Europe/Amsterdam')
-        start_dt_utc = start_dt.in_tz('UTC').format('YYYY-MM-DDTHH:MM:SSZ')
         end_dt = pendulum.parse(end_date, tz='Europe/Amsterdam')
-        end_dt_utc = start_dt.in_tz('UTC').format('YYYY-MM-DDTHH:MM:SSZ')
-        result = context.obj['opsgenie'].set_override_scheduled(team_name, start_dt_utc, end_dt_utc, engineer)
+        result = context.obj['opsgenie'].set_override_scheduled(team_name, start_dt.isoformat(), end_dt.isoformat(), engineer)
     else:
         raise click.UsageError(
             "Specify the amount of hours you want to override the schedule (using --hours), \
